@@ -38,6 +38,7 @@ class backgrounds(TemplateFormat):
     convert = None
     prefix = None
     stretch = False
+    mirror = False
     fallback_md5fn = "md5sum"
 
     def prepare(self):
@@ -62,6 +63,9 @@ class backgrounds(TemplateFormat):
         self.chroot_cmd = getProgPath('/bin/chroot')
         self.chroot_path = rpath
 
+    def setMirror(self):
+        self.mirror = True
+
     def setSource(self, source):
         self.source = source
 
@@ -72,7 +76,11 @@ class backgrounds(TemplateFormat):
         self.prefix = prefix
 
     def getImageMD5(self, source, resolutions=()):
-        return hashlib.md5(readFile(source)+"\n".join(resolutions)).hexdigest()
+        if source:
+            data = readFile(source)
+        else:
+            data = ""
+        return hashlib.md5(data+"\n".join(resolutions)).hexdigest()
 
     def setStretch(self, stretch):
         self.stretch = stretch
@@ -135,8 +143,8 @@ class backgrounds(TemplateFormat):
                                           packages="media-gfx/imagemagick")))
             return False
         if not self.source:
-            self.setError(_("format=backgrounds need 'link' parameter"))
-            return False
+            if not self.mirror:
+                return ""
         if not self.convert:
             self.convert = self.source.rpartition(".")[2].lower()
         if self.convert not in self.objVar.Get('cl_image_formats'):
@@ -145,10 +153,7 @@ class backgrounds(TemplateFormat):
         reRule = re.compile("^(\d+)x(\d+)$")
         if not rootPath:
             rootPath = '/'
-        source = os.path.normpath(pathJoin(rootPath, self.source))
-        if not os.path.exists(source):
-            self.setError(_("File %s not found") % source)
-            return False
+
         if self.prefix is None:
             workdir, prefix = os.path.split(nameFile)
         else:
@@ -159,12 +164,21 @@ class backgrounds(TemplateFormat):
                                   re.sub("[-._]+$", "", prefix))
         else:
             md5_fn = os.path.join(workdir, self.fallback_md5fn)
-        self.source_width, self.source_height = \
-            self.get_image_resolution(source)
-        if not self.source_width:
-            self.setError(_("Failed to detect resolution for image '%s'") %
-                          source)
-            return False
+        if not self.source:
+            source = None
+        else:
+            source = os.path.normpath(pathJoin(rootPath, self.source))
+            if not os.path.exists(source):
+                source = None
+            else:
+                self.source_width, self.source_height = \
+                    self.get_image_resolution(source)
+                if not self.source_width:
+                    self.setError(
+                        _("Failed to detect resolution for image '%s'") %
+                        source)
+                    return False
+
         if self.text.strip():
             text_list = self.text.split("\n")
         else:
@@ -195,32 +209,35 @@ class backgrounds(TemplateFormat):
                 fn = os.path.split(remove_fn)[1]
                 if re_remove.match(fn):
                     removed_files.append(remove_fn)
-        for resolution in resolutions:
-            rule_match = reRule.search(resolution)
-            if not rule_match:
-                self.setError(
-                    _("Wrong 'backgrounds' resolution: %s") % resolution)
-                return False
-            width, height = rule_match.groups()
-            width = int(width)
-            height = int(height)
+        if source:
+            for resolution in resolutions:
+                rule_match = reRule.search(resolution)
+                if not rule_match:
+                    self.setError(
+                        _("Wrong 'backgrounds' resolution: %s") % resolution)
+                    return False
+                width, height = rule_match.groups()
+                width = int(width)
+                height = int(height)
 
-            if only_one:
-                image_fn = pathJoin(workdir, prefix)
-            else:
-                image_fn = pathJoin(workdir, "%s%s.%s" % (
-                    prefix, resolution, self.convert))
-            if self._create_image(source, image_fn, width, height,
-                                  force=self.stretch):
-                if image_fn in removed_files:
-                    removed_files.remove(image_fn)
-                image_files.append(image_fn)
-            else:
-                self.parent.printWARNING(
-                    _("Skipped creation of the image with %s resolution") % (
-                        "%dx%d" % (width, height)))
-        with writeFile(md5_fn) as f:
-            f.write("%s\n" % image_md5)
+                if only_one:
+                    image_fn = pathJoin(workdir, prefix)
+                else:
+                    image_fn = pathJoin(workdir, "%s%s.%s" % (
+                        prefix, resolution, self.convert))
+                if self._create_image(source, image_fn, width, height,
+                                      force=self.stretch):
+                    if image_fn in removed_files:
+                        removed_files.remove(image_fn)
+                    image_files.append(image_fn)
+                else:
+                    self.parent.printWARNING(
+                        _("Skipped creation of the image with %s resolution") % (
+                            "%dx%d" % (width, height)))
+            with writeFile(md5_fn) as f:
+                f.write("%s\n" % image_md5)
+        else:
+            removed_files.append(md5_fn)
         self.changed_files.append(md5_fn)
         for remove_fn in removed_files:
             try:
