@@ -207,11 +207,14 @@ class VariableClResolutions(Variable):
     def get(self):
         if self.Get('cl_chroot_status') == 'off':
             try:
-                return list({
+                values = filter(None, list({
                     self.Get('install.os_install_fb_resolution'),
-                    self.Get('install.os_install_x11_resolution')})
+                    self.Get('install.os_install_x11_resolution')}))
+                if values:
+                    return values
             except DataVarsError:
                 pass
+            return ["1024x768"]
         return self.fallback_value
 
 
